# PulpPythonClient::ContentPackagesApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ContentPackagesApi.md#create) | **POST** /pulp/api/v3/content/python/packages/ | Create a python package content
[**list**](ContentPackagesApi.md#list) | **GET** /pulp/api/v3/content/python/packages/ | List python package contents
[**read**](ContentPackagesApi.md#read) | **GET** {python_python_package_content_href} | Inspect a python package content



## create

> AsyncOperationResponse create(relative_path, opts)

Create a python package content

Trigger an asynchronous task to create content,optionally create new repository version.

### Example

```ruby
# load the gem
require 'pulp_python_client'
# setup authorization
PulpPythonClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpPythonClient::ContentPackagesApi.new
relative_path = 'relative_path_example' # String | Path where the artifact is located relative to distributions base_path
opts = {
  artifact: 'artifact_example', # String | Artifact file representing the physical content
  file: File.new('/path/to/file'), # File | An uploaded file that may be turned into the artifact of the content unit.
  repository: 'repository_example', # String | A URI of a repository the new content unit should be associated with.
  upload: 'upload_example', # String | An uncommitted upload that may be turned into the artifact of the content unit.
  sha256: '', # String | The SHA256 digest of this package.
  summary: 'summary_example', # String | A one-line summary of what the package does.
  description: 'description_example', # String | A longer description of the package that can run to several paragraphs.
  description_content_type: 'description_content_type_example', # String | A string stating the markup syntax (if any) used in the distribution’s description, so that tools can intelligently render the description.
  keywords: 'keywords_example', # String | Additional keywords to be used to assist searching for the package in a larger catalog.
  home_page: 'home_page_example', # String | The URL for the package's home page.
  download_url: 'download_url_example', # String | Legacy field denoting the URL from which this package can be downloaded.
  author: 'author_example', # String | Text containing the author's name. Contact information can also be added, separated with newlines.
  author_email: 'author_email_example', # String | The author's e-mail address. 
  maintainer: 'maintainer_example', # String | The maintainer's name at a minimum; additional contact information may be provided.
  maintainer_email: 'maintainer_email_example', # String | The maintainer's e-mail address.
  license: 'license_example', # String | Text indicating the license covering the distribution
  requires_python: 'requires_python_example', # String | The Python version(s) that the distribution is guaranteed to be compatible with.
  project_url: 'project_url_example', # String | A browsable URL for the project and a label for it, separated by a comma.
  project_urls: nil, # Object | A dictionary of labels and URLs for the project.
  platform: 'platform_example', # String | A comma-separated list of platform specifications, summarizing the operating systems supported by the package.
  supported_platform: 'supported_platform_example', # String | Field to specify the OS and CPU for which the binary package was compiled. 
  requires_dist: nil, # Object | A JSON list containing names of some other distutils project required by this distribution.
  provides_dist: nil, # Object | A JSON list containing names of a Distutils project which is contained within this distribution.
  obsoletes_dist: nil, # Object | A JSON list containing names of a distutils project's distribution which this distribution renders obsolete, meaning that the two projects should not be installed at the same time.
  requires_external: nil, # Object | A JSON list containing some dependency in the system that the distribution is to be used.
  classifiers: nil # Object | A JSON list containing classification values for a Python package.
}

begin
  #Create a python package content
  result = api_instance.create(relative_path, opts)
  p result
rescue PulpPythonClient::ApiError => e
  puts "Exception when calling ContentPackagesApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **relative_path** | **String**| Path where the artifact is located relative to distributions base_path | 
 **artifact** | **String**| Artifact file representing the physical content | [optional] 
 **file** | **File**| An uploaded file that may be turned into the artifact of the content unit. | [optional] 
 **repository** | **String**| A URI of a repository the new content unit should be associated with. | [optional] 
 **upload** | **String**| An uncommitted upload that may be turned into the artifact of the content unit. | [optional] 
 **sha256** | **String**| The SHA256 digest of this package. | [optional] [default to &#39;&#39;]
 **summary** | **String**| A one-line summary of what the package does. | [optional] 
 **description** | **String**| A longer description of the package that can run to several paragraphs. | [optional] 
 **description_content_type** | **String**| A string stating the markup syntax (if any) used in the distribution’s description, so that tools can intelligently render the description. | [optional] 
 **keywords** | **String**| Additional keywords to be used to assist searching for the package in a larger catalog. | [optional] 
 **home_page** | **String**| The URL for the package&#39;s home page. | [optional] 
 **download_url** | **String**| Legacy field denoting the URL from which this package can be downloaded. | [optional] 
 **author** | **String**| Text containing the author&#39;s name. Contact information can also be added, separated with newlines. | [optional] 
 **author_email** | **String**| The author&#39;s e-mail address.  | [optional] 
 **maintainer** | **String**| The maintainer&#39;s name at a minimum; additional contact information may be provided. | [optional] 
 **maintainer_email** | **String**| The maintainer&#39;s e-mail address. | [optional] 
 **license** | **String**| Text indicating the license covering the distribution | [optional] 
 **requires_python** | **String**| The Python version(s) that the distribution is guaranteed to be compatible with. | [optional] 
 **project_url** | **String**| A browsable URL for the project and a label for it, separated by a comma. | [optional] 
 **project_urls** | [**Object**](Object.md)| A dictionary of labels and URLs for the project. | [optional] 
 **platform** | **String**| A comma-separated list of platform specifications, summarizing the operating systems supported by the package. | [optional] 
 **supported_platform** | **String**| Field to specify the OS and CPU for which the binary package was compiled.  | [optional] 
 **requires_dist** | [**Object**](Object.md)| A JSON list containing names of some other distutils project required by this distribution. | [optional] 
 **provides_dist** | [**Object**](Object.md)| A JSON list containing names of a Distutils project which is contained within this distribution. | [optional] 
 **obsoletes_dist** | [**Object**](Object.md)| A JSON list containing names of a distutils project&#39;s distribution which this distribution renders obsolete, meaning that the two projects should not be installed at the same time. | [optional] 
 **requires_external** | [**Object**](Object.md)| A JSON list containing some dependency in the system that the distribution is to be used. | [optional] 
 **classifiers** | [**Object**](Object.md)| A JSON list containing classification values for a Python package. | [optional] 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: multipart/form-data, application/x-www-form-urlencoded
- **Accept**: application/json


## list

> PaginatedpythonPythonPackageContentResponseList list(opts)

List python package contents

 PythonPackageContent represents each individually installable Python package. In the Python ecosystem, this is called a Python Distribution, sometimes (ambiguously) refered to as a package. In Pulp Python, we refer to it as PythonPackageContent. Each PythonPackageContent corresponds to a single filename, for example `pulpcore-3.0.0rc1-py3-none-any.whl` or `pulpcore-3.0.0rc1.tar.gz`.

### Example

```ruby
# load the gem
require 'pulp_python_client'
# setup authorization
PulpPythonClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpPythonClient::ContentPackagesApi.new
opts = {
  author: 'author_example', # String | Filter results where author matches value
  author__in: ['author__in_example'], # Array<String> | Filter results where author is in a comma-separated list of values
  filename: 'filename_example', # String | Filter results where filename matches value
  filename__contains: 'filename__contains_example', # String | Filter results where filename contains value
  filename__in: ['filename__in_example'], # Array<String> | Filter results where filename is in a comma-separated list of values
  keywords__contains: 'keywords__contains_example', # String | Filter results where keywords contains value
  keywords__in: ['keywords__in_example'], # Array<String> | Filter results where keywords is in a comma-separated list of values
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | Filter results where name matches value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `filename` - Filename * `-filename` - Filename (descending) * `packagetype` - Packagetype * `-packagetype` - Packagetype (descending) * `name` - Name * `-name` - Name (descending) * `version` - Version * `-version` - Version (descending) * `sha256` - Sha256 * `-sha256` - Sha256 (descending) * `python_version` - Python version * `-python_version` - Python version (descending) * `metadata_version` - Metadata version * `-metadata_version` - Metadata version (descending) * `summary` - Summary * `-summary` - Summary (descending) * `description` - Description * `-description` - Description (descending) * `keywords` - Keywords * `-keywords` - Keywords (descending) * `home_page` - Home page * `-home_page` - Home page (descending) * `download_url` - Download url * `-download_url` - Download url (descending) * `author` - Author * `-author` - Author (descending) * `author_email` - Author email * `-author_email` - Author email (descending) * `maintainer` - Maintainer * `-maintainer` - Maintainer (descending) * `maintainer_email` - Maintainer email * `-maintainer_email` - Maintainer email (descending) * `license` - License * `-license` - License (descending) * `requires_python` - Requires python * `-requires_python` - Requires python (descending) * `project_url` - Project url * `-project_url` - Project url (descending) * `platform` - Platform * `-platform` - Platform (descending) * `supported_platform` - Supported platform * `-supported_platform` - Supported platform (descending) * `requires_dist` - Requires dist * `-requires_dist` - Requires dist (descending) * `provides_dist` - Provides dist * `-provides_dist` - Provides dist (descending) * `obsoletes_dist` - Obsoletes dist * `-obsoletes_dist` - Obsoletes dist (descending) * `requires_external` - Requires external * `-requires_external` - Requires external (descending) * `classifiers` - Classifiers * `-classifiers` - Classifiers (descending) * `project_urls` - Project urls * `-project_urls` - Project urls (descending) * `description_content_type` - Description content type * `-description_content_type` - Description content type (descending) * `pk` - Pk * `-pk` - Pk (descending)
  packagetype: 'packagetype_example', # String | Filter results where packagetype matches value  * `bdist_dmg` - bdist_dmg * `bdist_dumb` - bdist_dumb * `bdist_egg` - bdist_egg * `bdist_msi` - bdist_msi * `bdist_rpm` - bdist_rpm * `bdist_wheel` - bdist_wheel * `bdist_wininst` - bdist_wininst * `sdist` - sdist
  packagetype__in: ['packagetype__in_example'], # Array<String> | Filter results where packagetype is in a comma-separated list of values
  pulp_href__in: ['pulp_href__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_id__in: ['pulp_id__in_example'], # Array<String> | Multiple values may be separated by commas.
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  requires_python: 'requires_python_example', # String | Filter results where requires_python matches value
  requires_python__contains: 'requires_python__contains_example', # String | Filter results where requires_python contains value
  requires_python__in: ['requires_python__in_example'], # Array<String> | Filter results where requires_python is in a comma-separated list of values
  sha256: 'sha256_example', # String | Filter results where sha256 matches value
  sha256__in: ['sha256__in_example'], # Array<String> | Filter results where sha256 is in a comma-separated list of values
  version: 'version_example', # String | Filter results where version matches value
  version__gt: 'version__gt_example', # String | Filter results where version is greater than value
  version__gte: 'version__gte_example', # String | Filter results where version is greater than or equal to value
  version__lt: 'version__lt_example', # String | Filter results where version is less than value
  version__lte: 'version__lte_example', # String | Filter results where version is less than or equal to value
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #List python package contents
  result = api_instance.list(opts)
  p result
rescue PulpPythonClient::ApiError => e
  puts "Exception when calling ContentPackagesApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **author** | **String**| Filter results where author matches value | [optional] 
 **author__in** | [**Array&lt;String&gt;**](String.md)| Filter results where author is in a comma-separated list of values | [optional] 
 **filename** | **String**| Filter results where filename matches value | [optional] 
 **filename__contains** | **String**| Filter results where filename contains value | [optional] 
 **filename__in** | [**Array&lt;String&gt;**](String.md)| Filter results where filename is in a comma-separated list of values | [optional] 
 **keywords__contains** | **String**| Filter results where keywords contains value | [optional] 
 **keywords__in** | [**Array&lt;String&gt;**](String.md)| Filter results where keywords is in a comma-separated list of values | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**| Filter results where name matches value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | [**Array&lt;String&gt;**](String.md)| Ordering  * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;pulp_type&#x60; - Pulp type * &#x60;-pulp_type&#x60; - Pulp type (descending) * &#x60;upstream_id&#x60; - Upstream id * &#x60;-upstream_id&#x60; - Upstream id (descending) * &#x60;timestamp_of_interest&#x60; - Timestamp of interest * &#x60;-timestamp_of_interest&#x60; - Timestamp of interest (descending) * &#x60;filename&#x60; - Filename * &#x60;-filename&#x60; - Filename (descending) * &#x60;packagetype&#x60; - Packagetype * &#x60;-packagetype&#x60; - Packagetype (descending) * &#x60;name&#x60; - Name * &#x60;-name&#x60; - Name (descending) * &#x60;version&#x60; - Version * &#x60;-version&#x60; - Version (descending) * &#x60;sha256&#x60; - Sha256 * &#x60;-sha256&#x60; - Sha256 (descending) * &#x60;python_version&#x60; - Python version * &#x60;-python_version&#x60; - Python version (descending) * &#x60;metadata_version&#x60; - Metadata version * &#x60;-metadata_version&#x60; - Metadata version (descending) * &#x60;summary&#x60; - Summary * &#x60;-summary&#x60; - Summary (descending) * &#x60;description&#x60; - Description * &#x60;-description&#x60; - Description (descending) * &#x60;keywords&#x60; - Keywords * &#x60;-keywords&#x60; - Keywords (descending) * &#x60;home_page&#x60; - Home page * &#x60;-home_page&#x60; - Home page (descending) * &#x60;download_url&#x60; - Download url * &#x60;-download_url&#x60; - Download url (descending) * &#x60;author&#x60; - Author * &#x60;-author&#x60; - Author (descending) * &#x60;author_email&#x60; - Author email * &#x60;-author_email&#x60; - Author email (descending) * &#x60;maintainer&#x60; - Maintainer * &#x60;-maintainer&#x60; - Maintainer (descending) * &#x60;maintainer_email&#x60; - Maintainer email * &#x60;-maintainer_email&#x60; - Maintainer email (descending) * &#x60;license&#x60; - License * &#x60;-license&#x60; - License (descending) * &#x60;requires_python&#x60; - Requires python * &#x60;-requires_python&#x60; - Requires python (descending) * &#x60;project_url&#x60; - Project url * &#x60;-project_url&#x60; - Project url (descending) * &#x60;platform&#x60; - Platform * &#x60;-platform&#x60; - Platform (descending) * &#x60;supported_platform&#x60; - Supported platform * &#x60;-supported_platform&#x60; - Supported platform (descending) * &#x60;requires_dist&#x60; - Requires dist * &#x60;-requires_dist&#x60; - Requires dist (descending) * &#x60;provides_dist&#x60; - Provides dist * &#x60;-provides_dist&#x60; - Provides dist (descending) * &#x60;obsoletes_dist&#x60; - Obsoletes dist * &#x60;-obsoletes_dist&#x60; - Obsoletes dist (descending) * &#x60;requires_external&#x60; - Requires external * &#x60;-requires_external&#x60; - Requires external (descending) * &#x60;classifiers&#x60; - Classifiers * &#x60;-classifiers&#x60; - Classifiers (descending) * &#x60;project_urls&#x60; - Project urls * &#x60;-project_urls&#x60; - Project urls (descending) * &#x60;description_content_type&#x60; - Description content type * &#x60;-description_content_type&#x60; - Description content type (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending) | [optional] 
 **packagetype** | **String**| Filter results where packagetype matches value  * &#x60;bdist_dmg&#x60; - bdist_dmg * &#x60;bdist_dumb&#x60; - bdist_dumb * &#x60;bdist_egg&#x60; - bdist_egg * &#x60;bdist_msi&#x60; - bdist_msi * &#x60;bdist_rpm&#x60; - bdist_rpm * &#x60;bdist_wheel&#x60; - bdist_wheel * &#x60;bdist_wininst&#x60; - bdist_wininst * &#x60;sdist&#x60; - sdist | [optional] 
 **packagetype__in** | [**Array&lt;String&gt;**](String.md)| Filter results where packagetype is in a comma-separated list of values | [optional] 
 **pulp_href__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_id__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **requires_python** | **String**| Filter results where requires_python matches value | [optional] 
 **requires_python__contains** | **String**| Filter results where requires_python contains value | [optional] 
 **requires_python__in** | [**Array&lt;String&gt;**](String.md)| Filter results where requires_python is in a comma-separated list of values | [optional] 
 **sha256** | **String**| Filter results where sha256 matches value | [optional] 
 **sha256__in** | [**Array&lt;String&gt;**](String.md)| Filter results where sha256 is in a comma-separated list of values | [optional] 
 **version** | **String**| Filter results where version matches value | [optional] 
 **version__gt** | **String**| Filter results where version is greater than value | [optional] 
 **version__gte** | **String**| Filter results where version is greater than or equal to value | [optional] 
 **version__lt** | **String**| Filter results where version is less than value | [optional] 
 **version__lte** | **String**| Filter results where version is less than or equal to value | [optional] 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedpythonPythonPackageContentResponseList**](PaginatedpythonPythonPackageContentResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> PythonPythonPackageContentResponse read(python_python_package_content_href, opts)

Inspect a python package content

 PythonPackageContent represents each individually installable Python package. In the Python ecosystem, this is called a Python Distribution, sometimes (ambiguously) refered to as a package. In Pulp Python, we refer to it as PythonPackageContent. Each PythonPackageContent corresponds to a single filename, for example `pulpcore-3.0.0rc1-py3-none-any.whl` or `pulpcore-3.0.0rc1.tar.gz`.

### Example

```ruby
# load the gem
require 'pulp_python_client'
# setup authorization
PulpPythonClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpPythonClient::ContentPackagesApi.new
python_python_package_content_href = 'python_python_package_content_href_example' # String | 
opts = {
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #Inspect a python package content
  result = api_instance.read(python_python_package_content_href, opts)
  p result
rescue PulpPythonClient::ApiError => e
  puts "Exception when calling ContentPackagesApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **python_python_package_content_href** | **String**|  | 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PythonPythonPackageContentResponse**](PythonPythonPackageContentResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

