# PulpPythonClient::RemotesPythonApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](RemotesPythonApi.md#create) | **POST** /pulp/api/v3/remotes/python/python/ | Create a python remote
[**delete**](RemotesPythonApi.md#delete) | **DELETE** {python_python_remote_href} | Delete a python remote
[**from_bandersnatch**](RemotesPythonApi.md#from_bandersnatch) | **POST** /pulp/api/v3/remotes/python/python/from_bandersnatch/ | Create from Bandersnatch
[**list**](RemotesPythonApi.md#list) | **GET** /pulp/api/v3/remotes/python/python/ | List python remotes
[**partial_update**](RemotesPythonApi.md#partial_update) | **PATCH** {python_python_remote_href} | Update a python remote
[**read**](RemotesPythonApi.md#read) | **GET** {python_python_remote_href} | Inspect a python remote
[**update**](RemotesPythonApi.md#update) | **PUT** {python_python_remote_href} | Update a python remote



## create

> PythonPythonRemoteResponse create(python_python_remote)

Create a python remote

 Python Remotes are representations of an external repository of Python content, eg. PyPI.  Fields include upstream repository config. Python Remotes are also used to `sync` from upstream repositories, and contains sync settings.

### Example

```ruby
# load the gem
require 'pulp_python_client'
# setup authorization
PulpPythonClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpPythonClient::RemotesPythonApi.new
python_python_remote = PulpPythonClient::PythonPythonRemote.new # PythonPythonRemote | 

begin
  #Create a python remote
  result = api_instance.create(python_python_remote)
  p result
rescue PulpPythonClient::ApiError => e
  puts "Exception when calling RemotesPythonApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **python_python_remote** | [**PythonPythonRemote**](PythonPythonRemote.md)|  | 

### Return type

[**PythonPythonRemoteResponse**](PythonPythonRemoteResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(python_python_remote_href)

Delete a python remote

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulp_python_client'
# setup authorization
PulpPythonClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpPythonClient::RemotesPythonApi.new
python_python_remote_href = 'python_python_remote_href_example' # String | 

begin
  #Delete a python remote
  result = api_instance.delete(python_python_remote_href)
  p result
rescue PulpPythonClient::ApiError => e
  puts "Exception when calling RemotesPythonApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **python_python_remote_href** | **String**|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## from_bandersnatch

> PythonPythonRemoteResponse from_bandersnatch(config, name, opts)

Create from Bandersnatch

 Takes the fields specified in the Bandersnatch config and creates a Python Remote from it.

### Example

```ruby
# load the gem
require 'pulp_python_client'
# setup authorization
PulpPythonClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpPythonClient::RemotesPythonApi.new
config = File.new('/path/to/file') # File | A Bandersnatch config that may be used to construct a Python Remote.
name = 'name_example' # String | A unique name for this remote
opts = {
  policy: PulpPythonClient::PolicyEnum.new # PolicyEnum | The policy to use when downloading content. The possible values include: 'immediate', 'on_demand', and 'streamed'. 'on_demand' is the default.  * `immediate` - When syncing, download all metadata and content now. * `on_demand` - When syncing, download metadata, but do not download content now. Instead, download content as clients request it, and save it in Pulp to be served for future client requests. * `streamed` - When syncing, download metadata, but do not download content now. Instead,download content as clients request it, but never save it in Pulp. This causes future requests for that same content to have to be downloaded again.
}

begin
  #Create from Bandersnatch
  result = api_instance.from_bandersnatch(config, name, opts)
  p result
rescue PulpPythonClient::ApiError => e
  puts "Exception when calling RemotesPythonApi->from_bandersnatch: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **config** | **File**| A Bandersnatch config that may be used to construct a Python Remote. | 
 **name** | **String**| A unique name for this remote | 
 **policy** | [**PolicyEnum**](PolicyEnum.md)| The policy to use when downloading content. The possible values include: &#39;immediate&#39;, &#39;on_demand&#39;, and &#39;streamed&#39;. &#39;on_demand&#39; is the default.  * &#x60;immediate&#x60; - When syncing, download all metadata and content now. * &#x60;on_demand&#x60; - When syncing, download metadata, but do not download content now. Instead, download content as clients request it, and save it in Pulp to be served for future client requests. * &#x60;streamed&#x60; - When syncing, download metadata, but do not download content now. Instead,download content as clients request it, but never save it in Pulp. This causes future requests for that same content to have to be downloaded again. | [optional] 

### Return type

[**PythonPythonRemoteResponse**](PythonPythonRemoteResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: multipart/form-data, application/x-www-form-urlencoded
- **Accept**: application/json


## list

> PaginatedpythonPythonRemoteResponseList list(opts)

List python remotes

 Python Remotes are representations of an external repository of Python content, eg. PyPI.  Fields include upstream repository config. Python Remotes are also used to `sync` from upstream repositories, and contains sync settings.

### Example

```ruby
# load the gem
require 'pulp_python_client'
# setup authorization
PulpPythonClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpPythonClient::RemotesPythonApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | Filter results where name matches value
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `name` - Name * `-name` - Name (descending) * `pulp_labels` - Pulp labels * `-pulp_labels` - Pulp labels (descending) * `url` - Url * `-url` - Url (descending) * `ca_cert` - Ca cert * `-ca_cert` - Ca cert (descending) * `client_cert` - Client cert * `-client_cert` - Client cert (descending) * `client_key` - Client key * `-client_key` - Client key (descending) * `tls_validation` - Tls validation * `-tls_validation` - Tls validation (descending) * `username` - Username * `-username` - Username (descending) * `password` - Password * `-password` - Password (descending) * `proxy_url` - Proxy url * `-proxy_url` - Proxy url (descending) * `proxy_username` - Proxy username * `-proxy_username` - Proxy username (descending) * `proxy_password` - Proxy password * `-proxy_password` - Proxy password (descending) * `download_concurrency` - Download concurrency * `-download_concurrency` - Download concurrency (descending) * `max_retries` - Max retries * `-max_retries` - Max retries (descending) * `policy` - Policy * `-policy` - Policy (descending) * `total_timeout` - Total timeout * `-total_timeout` - Total timeout (descending) * `connect_timeout` - Connect timeout * `-connect_timeout` - Connect timeout (descending) * `sock_connect_timeout` - Sock connect timeout * `-sock_connect_timeout` - Sock connect timeout (descending) * `sock_read_timeout` - Sock read timeout * `-sock_read_timeout` - Sock read timeout (descending) * `headers` - Headers * `-headers` - Headers (descending) * `rate_limit` - Rate limit * `-rate_limit` - Rate limit (descending) * `pk` - Pk * `-pk` - Pk (descending)
  pulp_href__in: ['pulp_href__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_id__in: ['pulp_id__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_label_select: 'pulp_label_select_example', # String | Filter labels by search string
  pulp_last_updated: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated matches value
  pulp_last_updated__gt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is greater than value
  pulp_last_updated__gte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is greater than or equal to value
  pulp_last_updated__lt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is less than value
  pulp_last_updated__lte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is less than or equal to value
  pulp_last_updated__range: [DateTime.parse('2013-10-20T19:20:30+01:00')], # Array<DateTime> | Filter results where pulp_last_updated is between two comma separated values
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #List python remotes
  result = api_instance.list(opts)
  p result
rescue PulpPythonClient::ApiError => e
  puts "Exception when calling RemotesPythonApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**| Filter results where name matches value | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | [**Array&lt;String&gt;**](String.md)| Ordering  * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;pulp_type&#x60; - Pulp type * &#x60;-pulp_type&#x60; - Pulp type (descending) * &#x60;name&#x60; - Name * &#x60;-name&#x60; - Name (descending) * &#x60;pulp_labels&#x60; - Pulp labels * &#x60;-pulp_labels&#x60; - Pulp labels (descending) * &#x60;url&#x60; - Url * &#x60;-url&#x60; - Url (descending) * &#x60;ca_cert&#x60; - Ca cert * &#x60;-ca_cert&#x60; - Ca cert (descending) * &#x60;client_cert&#x60; - Client cert * &#x60;-client_cert&#x60; - Client cert (descending) * &#x60;client_key&#x60; - Client key * &#x60;-client_key&#x60; - Client key (descending) * &#x60;tls_validation&#x60; - Tls validation * &#x60;-tls_validation&#x60; - Tls validation (descending) * &#x60;username&#x60; - Username * &#x60;-username&#x60; - Username (descending) * &#x60;password&#x60; - Password * &#x60;-password&#x60; - Password (descending) * &#x60;proxy_url&#x60; - Proxy url * &#x60;-proxy_url&#x60; - Proxy url (descending) * &#x60;proxy_username&#x60; - Proxy username * &#x60;-proxy_username&#x60; - Proxy username (descending) * &#x60;proxy_password&#x60; - Proxy password * &#x60;-proxy_password&#x60; - Proxy password (descending) * &#x60;download_concurrency&#x60; - Download concurrency * &#x60;-download_concurrency&#x60; - Download concurrency (descending) * &#x60;max_retries&#x60; - Max retries * &#x60;-max_retries&#x60; - Max retries (descending) * &#x60;policy&#x60; - Policy * &#x60;-policy&#x60; - Policy (descending) * &#x60;total_timeout&#x60; - Total timeout * &#x60;-total_timeout&#x60; - Total timeout (descending) * &#x60;connect_timeout&#x60; - Connect timeout * &#x60;-connect_timeout&#x60; - Connect timeout (descending) * &#x60;sock_connect_timeout&#x60; - Sock connect timeout * &#x60;-sock_connect_timeout&#x60; - Sock connect timeout (descending) * &#x60;sock_read_timeout&#x60; - Sock read timeout * &#x60;-sock_read_timeout&#x60; - Sock read timeout (descending) * &#x60;headers&#x60; - Headers * &#x60;-headers&#x60; - Headers (descending) * &#x60;rate_limit&#x60; - Rate limit * &#x60;-rate_limit&#x60; - Rate limit (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending) | [optional] 
 **pulp_href__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_id__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_label_select** | **String**| Filter labels by search string | [optional] 
 **pulp_last_updated** | **DateTime**| Filter results where pulp_last_updated matches value | [optional] 
 **pulp_last_updated__gt** | **DateTime**| Filter results where pulp_last_updated is greater than value | [optional] 
 **pulp_last_updated__gte** | **DateTime**| Filter results where pulp_last_updated is greater than or equal to value | [optional] 
 **pulp_last_updated__lt** | **DateTime**| Filter results where pulp_last_updated is less than value | [optional] 
 **pulp_last_updated__lte** | **DateTime**| Filter results where pulp_last_updated is less than or equal to value | [optional] 
 **pulp_last_updated__range** | [**Array&lt;DateTime&gt;**](DateTime.md)| Filter results where pulp_last_updated is between two comma separated values | [optional] 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedpythonPythonRemoteResponseList**](PaginatedpythonPythonRemoteResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(python_python_remote_href, patchedpython_python_remote)

Update a python remote

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_python_client'
# setup authorization
PulpPythonClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpPythonClient::RemotesPythonApi.new
python_python_remote_href = 'python_python_remote_href_example' # String | 
patchedpython_python_remote = PulpPythonClient::PatchedpythonPythonRemote.new # PatchedpythonPythonRemote | 

begin
  #Update a python remote
  result = api_instance.partial_update(python_python_remote_href, patchedpython_python_remote)
  p result
rescue PulpPythonClient::ApiError => e
  puts "Exception when calling RemotesPythonApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **python_python_remote_href** | **String**|  | 
 **patchedpython_python_remote** | [**PatchedpythonPythonRemote**](PatchedpythonPythonRemote.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> PythonPythonRemoteResponse read(python_python_remote_href, opts)

Inspect a python remote

 Python Remotes are representations of an external repository of Python content, eg. PyPI.  Fields include upstream repository config. Python Remotes are also used to `sync` from upstream repositories, and contains sync settings.

### Example

```ruby
# load the gem
require 'pulp_python_client'
# setup authorization
PulpPythonClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpPythonClient::RemotesPythonApi.new
python_python_remote_href = 'python_python_remote_href_example' # String | 
opts = {
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #Inspect a python remote
  result = api_instance.read(python_python_remote_href, opts)
  p result
rescue PulpPythonClient::ApiError => e
  puts "Exception when calling RemotesPythonApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **python_python_remote_href** | **String**|  | 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PythonPythonRemoteResponse**](PythonPythonRemoteResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update

> AsyncOperationResponse update(python_python_remote_href, python_python_remote)

Update a python remote

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_python_client'
# setup authorization
PulpPythonClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpPythonClient::RemotesPythonApi.new
python_python_remote_href = 'python_python_remote_href_example' # String | 
python_python_remote = PulpPythonClient::PythonPythonRemote.new # PythonPythonRemote | 

begin
  #Update a python remote
  result = api_instance.update(python_python_remote_href, python_python_remote)
  p result
rescue PulpPythonClient::ApiError => e
  puts "Exception when calling RemotesPythonApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **python_python_remote_href** | **String**|  | 
 **python_python_remote** | [**PythonPythonRemote**](PythonPythonRemote.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

